powered by
Takes a data frame and displays the location of missing data. The missings can be clustered and be displayed together.
PlotMiss(x, col = DescTools::hred, bg = SetAlpha(DescTools::hecru, 0.3), clust = FALSE, main = NULL, ...)
if clust is set to TRUE, the new order will be returned invisibly.
a data.frame to be analysed.
the colour of the missings.
the background colour of the plot.
logical, defining if the missings should be clustered. Default is FALSE.
FALSE
the main title.
the dots are passed to plot.
plot
Andri Signorell <[email protected]>, following an idea of Henk Harmsen <[email protected]>
A graphical display of the position of the missings can be help to detect dependencies or patterns within the missings.
hclust, CountCompCases
hclust
CountCompCases
PlotMiss(d.pizza, main="Missing pizza data")
Run the code above in your browser using DataLab